@@ -1,4 +1,5 @@
-package B::OPCheck;
+package B::OPCheck; # git description: 0.29-6-g1b4433f
+# ABSTRACT: PL_check hacks using Perl callbacks
 
 use 5.008;
 
@@ -9,9 +10,9 @@ use Carp;
 use XSLoader;
 use Scalar::Util;
 use Scope::Guard;
-use B::Utils ();
+use B::Utils 0.08 ();
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 XSLoader::load 'B::OPCheck', $VERSION;
 
@@ -48,10 +49,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 B::OPCheck - PL_check hacks using Perl callbacks
 
+=head1 VERSION
+
+version 0.30
+
 =head1 SYNOPSIS
 
     use B::Generate; # to change things
@@ -106,19 +113,50 @@ handling completely.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-OPCheck>
+(or L<bug-B-OPCheck@rt.cpan.org|mailto:bug-B-OPCheck@rt.cpan.org>).
+
 =head1 AUTHORS
 
-Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
-Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
+=over 4
 
-=head1 COPYRIGHT
+=item *
 
-Copyright 2008 by Chia-liang Kao, Yuval Kogman
+Chia-liang Kao <clkao@clkao.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=item *
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords Florian Ragwitz Karen Etheridge Alexandr Ciornii
+
+=over 4
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2009 by Chia-liang Kao, יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
